@@ -22,8 +22,8 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python2.7',
  'COREPYTHONPATH': ':plat-linux2:lib-tk:lib-old',
- 'COVERAGE_INFO': '/build/python2/src/Python-2.7.16/coverage.info',
- 'COVERAGE_REPORT': '/build/python2/src/Python-2.7.16/lcov-report',
+ 'COVERAGE_INFO': '/build/python2/src/Python-2.7.17/coverage.info',
+ 'COVERAGE_REPORT': '/build/python2/src/Python-2.7.17/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov report"',
  'CPPFLAGS': '-I. -IInclude -I./Include -D_FORTIFY_SOURCE=2',
  'CXX': 'g++ -pthread',
@@ -187,6 +187,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_LANGINFO_H': 1,
  'HAVE_LARGEFILE_SUPPORT': 1,
  'HAVE_LCHFLAGS': 0,
+ 'HAVE_LCHMOD': 0,
  'HAVE_LCHOWN': 1,
  'HAVE_LGAMMA': 1,
  'HAVE_LIBDL': 1,
@@ -464,7 +465,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'RANLIB': 'ranlib',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python2/src/Python-2.7.16',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python2/src/Python-2.7.17',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '',
@@ -492,7 +493,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
  'SO': '.so',
- 'SRCDIRS': 'Parser Objects Python Modules',
+ 'SRCDIRS': 'Parser Objects Python Modules Modules/_io',
  'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
@@ -507,7 +508,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'TESTOPTS': '-l',
  'TESTPATH': '',
  'TESTPROG': './Lib/test/regrtest.py',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python2/src/Python-2.7.16 ./python -Wd -3 -E -tt',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python2/src/Python-2.7.17 ./python -Wd -3 -E -tt',
  'TESTPYTHONOPTS': '',
  'THREADOBJ': 'Python/thread.o',
  'TIME_WITH_SYS_TIME': 1,
@@ -532,8 +533,8 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python2/src/Python-2.7.16',
- 'abs_srcdir': '/build/python2/src/Python-2.7.16',
+ 'abs_builddir': '/build/python2/src/Python-2.7.17',
+ 'abs_srcdir': '/build/python2/src/Python-2.7.17',
  'build': 'armv7l-unknown-linux-gnueabihf',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
